@@ -24,6 +24,10 @@ def render_template_file(template_filename, context):
 
 
 def read_yaml_file(filename):
-    with open(filename, 'r') as stream:
-        return yaml.load(stream)
+    contents = None
 
+    if os.path.isfile(filename):
+        with open(filename, 'r') as stream:
+            contents = yaml.load(stream)
+
+    return contents
